@@ -1,5 +1,5 @@
 #  Pyrogram - Telegram MTProto API Client Library for Python
-#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
+#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
 #
 #  This file is part of Pyrogram.
 #
@@ -18,26 +18,26 @@
 
 import asyncio
 import os
-import time
 from datetime import datetime
-from typing import Union, Optional
+from typing import Union, Optional, Callable, BinaryIO
 
+import pyrogram
 from pyrogram import types
 from pyrogram.file_id import FileId, FileType, PHOTO_TYPES
-from pyrogram.scaffold import Scaffold
 
 DEFAULT_DOWNLOAD_DIR = "downloads/"
 
 
-class DownloadMedia(Scaffold):
+class DownloadMedia:
     async def download_media(
-        self,
+        self: "pyrogram.Client",
         message: Union["types.Message", str],
         file_name: str = DEFAULT_DOWNLOAD_DIR,
+        in_memory: bool = False,
         block: bool = True,
-        progress: callable = None,
+        progress: Callable = None,
         progress_args: tuple = ()
-    ) -> Optional[str]:
+    ) -> Optional[Union[str, BinaryIO]]:
         """Download the media from a message.
 
         Parameters:
@@ -51,11 +51,16 @@ class DownloadMedia(Scaffold):
                 You can also specify a path for downloading files in a custom location: paths that end with "/"
                 are considered directories. All non-existent folders will be created automatically.
 
+            in_memory (``bool``, *optional*):
+                Pass True to download the media in-memory.
+                A binary file-like object with its attribute ".name" set will be returned.
+                Defaults to False.
+
             block (``bool``, *optional*):
                 Blocks the code execution until the file has been downloaded.
                 Defaults to True.
 
-            progress (``callable``, *optional*):
+            progress (``Callable``, *optional*):
                 Pass a callback function to view the file transmission progress.
                 The function must take *(current, total)* as positional arguments (look at Other Parameters below for a
                 detailed description) and will be called back each time a new file chunk has been successfully
@@ -78,27 +83,39 @@ class DownloadMedia(Scaffold):
                 You can either keep ``*args`` or add every single extra argument in your function signature.
 
         Returns:
-            ``str`` | ``None``: On success, the absolute path of the downloaded file is returned, otherwise, in case
-            the download failed or was deliberately stopped with :meth:`~pyrogram.Client.stop_transmission`, None is
-            returned.
+            ``str`` | ``None`` | ``BinaryIO``: On success, the absolute path of the downloaded file is returned,
+            otherwise, in case the download failed or was deliberately stopped with
+            :meth:`~pyrogram.Client.stop_transmission`, None is returned.
+            Otherwise, in case ``in_memory=True``, a binary file-like object with its attribute ".name" set is returned.
 
         Raises:
             ValueError: if the message doesn't contain any downloadable media
 
         Example:
+            Download media to file
+
             .. code-block:: python
 
                 # Download from Message
-                app.download_media(message)
+                await app.download_media(message)
 
                 # Download from file id
-                app.download_media("CAADBAADzg4AAvLQYAEz_x2EOgdRwBYE")
+                await app.download_media(message.photo.file_id)
 
                 # Keep track of the progress while downloading
-                def progress(current, total):
+                async def progress(current, total):
                     print(f"{current * 100 / total:.1f}%")
 
-                app.download_media(message, progress=progress)
+                await app.download_media(message, progress=progress)
+
+            Download media in-memory
+
+            .. code-block:: python
+
+                file = await app.download_media(message, in_memory=True)
+
+                file_name = file.name
+                file_bytes = bytes(file.getbuffer())
         """
         available_media = ("audio", "document", "photo", "sticker", "animation", "video", "voice", "video_note",
                            "new_chat_photo")
@@ -125,7 +142,7 @@ class DownloadMedia(Scaffold):
         media_file_name = getattr(media, "file_name", "")
         file_size = getattr(media, "file_size", 0)
         mime_type = getattr(media, "mime_type", "")
-        date = getattr(media, "date", 0)
+        date = getattr(media, "date", None)
 
         directory, file_name = os.path.split(file_name)
         file_name = file_name or media_file_name or ""
@@ -153,12 +170,14 @@ class DownloadMedia(Scaffold):
 
             file_name = "{}_{}_{}{}".format(
                 FileType(file_id_obj.file_type).name.lower(),
-                datetime.fromtimestamp(date or time.time()).strftime("%Y-%m-%d_%H-%M-%S"),
+                (date or datetime.now()).strftime("%Y-%m-%d_%H-%M-%S"),
                 self.rnd_id(),
                 extension
             )
 
-        downloader = self.handle_download((file_id_obj, directory, file_name, file_size, progress, progress_args))
+        downloader = self.handle_download(
+            (file_id_obj, directory, file_name, in_memory, file_size, progress, progress_args)
+        )
 
         if block:
             return await downloader
